@@ -143,7 +143,8 @@ class ExpressSession(SessionAbstract):
                 if 'session_id' in self.cookie:
                     data = self.redis.get(self.cookie['session_id'])
                     if data:
-                        self.data = phpserialize.loads(data, object_hook=phpserialize.phpobject)
+                        self.data = phpserialize.loads(
+                            data, object_hook=phpserialize.phpobject)
                     else:
                         self.data = {}
                         for key in self.cookie:
@@ -175,16 +176,19 @@ class ExpressSession(SessionAbstract):
         if self.httponly:
             params['httponly'] = self.httponly
 
-        data = phpserialize.dumps(self.data, object_hook=phpserialize.phpobject)
+        data = phpserialize.dumps(
+            self.data, object_hook=phpserialize.phpobject)
         self.redis.set(self.cookie['session_id'], data)
-        response.set_cookie(self.name, urllib.quote_plus(self.crypt.encrypt(phpserialize.dumps(self.cookie))), **params)
+        response.set_cookie(self.name, urllib.quote_plus(
+            self.crypt.encrypt(phpserialize.dumps(self.cookie))), **params)
 
     def create(self):
         timestamp = calendar.timegm(time.gmtime())
 
         self.cookie['session_id'] = self.crypt.md5(uuid.uuid4().get_bytes())
         self.cookie['ip_address'] = request.remote_addr
-        self.cookie['user_agent'] = request.environ.get('HTTP_USER_AGENT')[0:50]
+        self.cookie['user_agent'] = request.environ.get(
+            'HTTP_USER_AGENT')[0:50]
         self.cookie['last_activity'] = timestamp
 
         max_age = self.lifetime if self.lifetime else self.one_day
@@ -202,10 +206,12 @@ class ExpressSession(SessionAbstract):
         if self.httponly:
             params['httponly'] = self.httponly
 
-        data = phpserialize.dumps(self.data, object_hook=phpserialize.phpobject)
+        data = phpserialize.dumps(
+            self.data, object_hook=phpserialize.phpobject)
         self.redis.set(self.cookie['session_id'], data)
         self.redis.expire(self.cookie['session_id'], max_age)
-        response.set_cookie(self.name, self.crypt.encrypt(phpserialize.dumps(self.cookie)), **params)
+        response.set_cookie(self.name, self.crypt.encrypt(
+            phpserialize.dumps(self.cookie)), **params)
 
     def __str__(self):
         return ':'.join([self.cookie['session_id'] if self.cookie['session_id'] else '', self.data.__str__()])
